==> sagua_0.2.0-1.tar.gz: sagua-0.2.0/include/imagebutton.h <==
#ifndef GUARD_imagebutton_h
#define GUARD_imagebutton_h
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file imagebutton.h
/// @brief Class for rollover image button header file.

#include <string>

#include <gtkmm/drawingarea.h>
#include <gtkmm/eventbox.h>

/// @brief Class for rollover image button.
///
/// If mouse is in the button area, display overImage.
///
/// If user click the button, display pressImage.
///
/// Otherwise display normalImage.
class ImageButton : public Gtk::EventBox
{
    public:
	ImageButton(const std::string& normal, const std::string& over, const std::string& press);
	virtual ~ImageButton();

	sigc::signal<void> SignalPress();

    private:
	ImageButton(const ImageButton&);
	ImageButton& operator=(const ImageButton&);

	Gtk::DrawingArea drawingArea_;
	Glib::RefPtr<Gdk::Pixbuf> normalImage_;
	Glib::RefPtr<Gdk::Pixbuf> overImage_;
	Glib::RefPtr<Gdk::Pixbuf> pressImage_;

	Glib::RefPtr<Gdk::Pixbuf> prevImage_;

	sigc::signal<void> signalPress_;	///< Signal variable to transmit signal to connected function when press button.

	bool OnBtnPress(GdkEventButton*);
	bool OnBtnRelease(GdkEventButton*);
	bool OnEnterNotify(GdkEventCrossing*);
	bool OnLeaveNotify(GdkEventCrossing*);
	bool OnExposeEvent(GdkEventExpose* ev);

};

#endif

==> sagua_0.2.3-1.tar.gz: sagua-0.2.3/include/imagebutton.h <==
#ifndef GUARD_imagebutton_h
#define GUARD_imagebutton_h
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file imagebutton.h
/// @brief Class for rollover image button header file.

#include <string>

#include <gtkmm/drawingarea.h>
#include <gtkmm/eventbox.h>

/// @brief Class for rollover image button.
///
/// If mouse is in the button area, display overImage.
///
/// If user click the button, display pressImage.
///
/// Otherwise display normalImage.
class ImageButton : public Gtk::EventBox
{
    public:
	ImageButton(const std::string& normal, const std::string& over, const std::string& press);
	virtual ~ImageButton();

	sigc::signal<void> SignalPress();

    private:
	ImageButton(const ImageButton&);
	ImageButton& operator=(const ImageButton&);

	Gtk::DrawingArea drawingArea_;
	Glib::RefPtr<Gdk::Pixbuf> normalImage_;
	Glib::RefPtr<Gdk::Pixbuf> overImage_;
	Glib::RefPtr<Gdk::Pixbuf> pressImage_;

	Glib::RefPtr<Gdk::Pixbuf> prevImage_;

	sigc::signal<void> signalPress_;	///< Signal variable to transmit signal to connected function when press button.

	void Render(Glib::RefPtr<Gdk::Pixbuf>& image)
	{
	    image->render_to_drawable_alpha(drawingArea_.get_window(), 0, 0, 0, 0,
		image->get_width(), image->get_height(),
		Gdk::PIXBUF_ALPHA_FULL, 0, Gdk::RGB_DITHER_NONE, 0, 0);
	}

	bool OnBtnPress(GdkEventButton* ev);
	bool OnBtnRelease(GdkEventButton* ev);
	bool OnEnterNotify(GdkEventCrossing* ev);
	bool OnLeaveNotify(GdkEventCrossing* ev);
	bool OnExposeEvent(GdkEventExpose* ev);

};

#endif
